//
//  NetworkAPI.swift
//  GitHub
//
//  Created by 曹云霄 on 2017/11/30.
//  Copyright © 2017年 曹云霄. All rights reserved.
//

import Foundation
import Moya
import Alamofire
import SwiftyJSON

public enum Service {
    // MARK: - 登录
    case Login(String,String)
    // MARK: - 待办事项查询
    case QueryTodo(QueryTodoModel)
    // MARK: - 新建工单查询来源
    case QuerySource()
    // MARK: - 新建工单服务类型
    case QueryServerType()
    // MARK: - 新建工单优先级
    case QueryPrority()
    // MARK: - 查询报事人
    case QueryInitiator()
    // MARK: - 查询位置
    case QueryPosition()
    // MARK: - 查询设施
    case QueryDevice(DeviceQueryModel)
    // MARK: - 提交工单
    case SubmitOrder(SaveRepairOrderModel)
    // MARK: - 查询工单列表
    case QueryRepairOrder(RepairOrderQuery)
}

extension Service: TargetType {
    public var baseURL: URL {
        return URL(string: BaseUrl)!
    }
    
    public var path: String {
        switch self {
        case .Login(let name, _):
            return String(format: loginUrl, name)
        case .QueryTodo(_):
            return todoUrl
        case .QuerySource:
            return sourceUrl
        case .QueryServerType:
            return serviceTypeUrl
        case .QueryPrority:
            return prorityUrl
        case .QueryInitiator():
            return initiatorUrl
        case .QueryPosition():
            return positionUrl
        case .QueryDevice(_):
            return deviceUrl
        case .SubmitOrder(_):
            let path = saveRepairOrderUrl + "?operator.operId=\(kUser().userCode!)&operator.operName=\(kUser().userName!)&time=\(NSDate().httpParameterString()!)"
            return path.urlEncoded()
        case .QueryRepairOrder(_):
            return repairOrderUrl
        }
    }
    
    public var method: Moya.Method {
        switch self {
        case .Login(_, _),
             .QueryTodo(_),
             .QueryPosition(),
             .QueryDevice(_),
             .SubmitOrder(_),
             .QueryRepairOrder(_),
             .QueryInitiator(_):
            return .post
        case .QuerySource(),
             .QueryServerType(),
             .QueryPrority():
            return .get
        }
    }
    
    public var sampleData: Data {
        return "Create post successfully".data(using: String.Encoding.utf8)!
    }
    
    public var task: Task {
        switch self {
        case .Login(_, let password):
            return .requestParameters(parameters: ["password": password,
                                                   "authenticode": "211534962"],
                                      encoding: JSONEncoding.default)
        case .QueryTodo(let model):
            return .requestParameters(parameters: model.toDictionary(),
                                      encoding: JSONEncoding.default)
        case .QuerySource(),
             .QueryServerType(),
             .QueryPrority():
            return .requestPlain
        case .QueryInitiator(),
             .QueryPosition():
            let model = EmptyModel()
            return .requestParameters(parameters: model.toJSON()!,
                                      encoding: JSONEncoding.default)
        case .QueryDevice(let queryModel):
            return .requestParameters(parameters: queryModel.toDictionary(),
                                     encoding: JSONEncoding.default)
        case .SubmitOrder(let submitModel):
            return .requestParameters(parameters: submitModel.toDictionary(),
                                      encoding: JSONEncoding.default)
        case .QueryRepairOrder(let queryModel):
            return .requestParameters(parameters: queryModel.toDictionary(),
                                      encoding: JSONEncoding.default)
        }
    }
    
    public var headers: [String : String]? {
        return ["device" : UIDevice.current.name]
    }
}












